@@ -2,7 +2,6 @@ import traceback
 from enum import Enum
 
 from testit_python_commons.models.outcome_type import OutcomeType
-from testit_python_commons.services.utils import Utils
 
 from .models.tags import TagType
 from .tags_parser import parse_tags
@@ -52,7 +51,7 @@ def parse_scenario(scenario):
         # 'completed_on': None
     }
 
-    if TagType.EXTERNAL_ID in tags:
+    if TagType.TITLE in tags:
         executable_test['title'] = tags[TagType.TITLE]
 
     if TagType.DESCRIPTION in tags:
@@ -86,7 +85,9 @@ def get_scenario_name(scenario):
 
 
 def get_scenario_external_id(scenario):
-    return Utils.get_hash(scenario.feature.filename + scenario.name)
+    from .utils import get_hash
+
+    return get_hash(scenario.feature.filename + scenario.name)
 
 
 def get_scenario_namespace(scenario):
@@ -96,7 +97,7 @@ def get_scenario_namespace(scenario):
 def get_scenario_parameters(scenario):
     row = scenario._row
 
-    return {name: value for name, value in zip(row.headings, row.cells)} if row else None
+    return {name: value for name, value in zip(row.headings, row.cells)} if row else {}
 
 
 def get_scenario_status(scenario):
